@@ -1,13 +1,14 @@
+local enemy = ...
+
 -- Blue Bullblin
 
-sol.main.include("enemies/generic_soldier")
-
-set_properties({
+require("enemies/generic_soldier")(enemy)
+enemy:set_properties({
   main_sprite = "enemies/blue_bullblin",
   sword_sprite = "enemies/blue_bullblin_sword",
-  life = 4,
+  life = 3,
   damage = 2,
-  play_hero_seen_sound = true,
+  play_hero_seen_sound = false,
   normal_speed = 32,
   faster_speed = 48,
 })
