@@ -1,13 +1,14 @@
--- Red Bullblin
+local enemy = ...
 
-sol.main.include("enemies/generic_soldier")
+-- Red Bullblin.
 
-set_properties({
+require("enemies/generic_soldier")(enemy)
+enemy:set_properties({
   main_sprite = "enemies/red_bullblin",
   sword_sprite = "enemies/red_bullblin_sword",
   life = 4,
-  damage = 2,
-  play_hero_seen_sound = true,
+  damage = 4,
+  play_hero_seen_sound = false,
   normal_speed = 32,
   faster_speed = 48,
 })
